# J.COp Vision
J.COp Vision is a computer vision toolkit to complement opencv workflow. It includes a lot of helper tools for computer vision.

The project started in July 2020 as a tool to teach computer vision for beginner.

# User Installation Guide
```
pip install jcopvision
```